==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/DataSourceAggregatedResultDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceAggregatedResultDescription } from "./DataSourceAggregatedResultDescription";
/**
 * @hidden
 */
var DataSourceAggregatedResultDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataSourceAggregatedResultDescriptionMetadata, _super);
    function DataSourceAggregatedResultDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceAggregatedResultDescriptionMetadata.b = function (a) {
        if (DataSourceAggregatedResultDescriptionMetadata.a == null) {
            DataSourceAggregatedResultDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceAggregatedResultDescriptionMetadata.c(DataSourceAggregatedResultDescriptionMetadata.a);
        }
        if (a.g(DataSourceAggregatedResultDescriptionMetadata.a)) {
            return;
        }
        a.s(DataSourceAggregatedResultDescriptionMetadata.a);
    };
    DataSourceAggregatedResultDescriptionMetadata.c = function (a) {
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("TransactionType", "ExportedType:string:TransactionType");
        a.item("TransactionType@names", "Add;Update;Delete");
        a.item("Keys", "Array:string");
        a.item("ValuesRef", "(w:Values,wf:Values)DataRef:object");
    };
    DataSourceAggregatedResultDescriptionMetadata.d = function (a) {
        DataSourceAggregatedResultDescriptionMetadata.b(a);
        a.u("DataSourceAggregatedResult", function () { return new DataSourceAggregatedResultDescription(); });
        a.t("DataSourceAggregatedResult", DataSourceAggregatedResultDescriptionMetadata.a);
    };
    DataSourceAggregatedResultDescriptionMetadata.$t = markType(DataSourceAggregatedResultDescriptionMetadata, 'DataSourceAggregatedResultDescriptionMetadata');
    DataSourceAggregatedResultDescriptionMetadata.a = null;
    return DataSourceAggregatedResultDescriptionMetadata;
}(Base));
export { DataSourceAggregatedResultDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/DataSourceAggregatedResultDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceAggregatedResultDescription } from "./DataSourceAggregatedResultDescription";
/**
 * @hidden
 */
var DataSourceAggregatedResultDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataSourceAggregatedResultDescriptionMetadata, _super);
    function DataSourceAggregatedResultDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceAggregatedResultDescriptionMetadata.b = function (a) {
        if (DataSourceAggregatedResultDescriptionMetadata.a == null) {
            DataSourceAggregatedResultDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceAggregatedResultDescriptionMetadata.c(DataSourceAggregatedResultDescriptionMetadata.a);
        }
        if (a.j(DataSourceAggregatedResultDescriptionMetadata.a)) {
            return;
        }
        a.y(DataSourceAggregatedResultDescriptionMetadata.a);
    };
    DataSourceAggregatedResultDescriptionMetadata.c = function (a) {
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("TransactionType", "ExportedType:string:TransactionType");
        a.item("TransactionType@names", "Add;Update;Delete");
        a.item("Keys", "Array:string");
        a.item("ValuesRef", "(w:Values,wf:Values)DataRef:object");
    };
    DataSourceAggregatedResultDescriptionMetadata.d = function (a) {
        DataSourceAggregatedResultDescriptionMetadata.b(a);
        a.aa("DataSourceAggregatedResult", function () { return new DataSourceAggregatedResultDescription(); });
        a.z("DataSourceAggregatedResult", DataSourceAggregatedResultDescriptionMetadata.a);
    };
    DataSourceAggregatedResultDescriptionMetadata.$t = markType(DataSourceAggregatedResultDescriptionMetadata, 'DataSourceAggregatedResultDescriptionMetadata');
    DataSourceAggregatedResultDescriptionMetadata.a = null;
    return DataSourceAggregatedResultDescriptionMetadata;
}(Base));
export { DataSourceAggregatedResultDescriptionMetadata };
